BurstParticle class

Inheritance
Annotations

Constructors

BurstParticle({required double x, required double y, required double speed, required double angle, required Color color})

Properties

angle double
getter/setter pair
color Color
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
radius double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speed double
getter/setter pair
x double
getter/setter pair
y double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update() → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited