FloatingParticle class

Inheritance
Annotations

Constructors

FloatingParticle(List<Color> colors, Size screenSize)

Properties

angle double
getter/setter pair
colors List<Color>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
paint Paint
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenSize Size
getter/setter pair
size double
getter/setter pair
speed double
getter/setter pair
x double
getter/setter pair
y double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
toString() String
A string representation of this object.
inherited
update() → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited