RainParticle class

Inheritance
Annotations

Constructors

RainParticle(Color color, Size screenSize)

Properties

color Color
final
hashCode int
The hash code for this object.
no setterinherited
length double
getter/setter pair
paint Paint
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenSize Size
final
speed double
getter/setter pair
x double
getter/setter pair
y double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
toString() String
A string representation of this object.
inherited
update() → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited