WidgetParticle class
Constructors
-
WidgetParticle(Size screenSize, List<
Widget> widgets)
Properties
- direction ↔ double
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- position ↔ Offset
-
getter/setter pair
- rotation ↔ double
-
getter/setter pair
- rotationSpeed ↔ double
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenSize → Size
-
final
- size ↔ double
-
getter/setter pair
- speedX ↔ double
-
getter/setter pair
- speedY ↔ double
-
getter/setter pair
- widget ↔ Widget
-
getter/setter pair
-
widgets
→ List<
Widget> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → void -
toString(
) → String -
A string representation of this object.
inherited
-
update(
) → void -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited