WindLine class

Inheritance
Annotations

Constructors

WindLine(Size screenSize, {bool isStrongWind = false})

Properties

hashCode int
The hash code for this object.
no setterinherited
isStrongWind bool
final
length double
getter/setter pair
opacity double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenSize Size
final
speedX double
getter/setter pair
waveAmplitude double
getter/setter pair
x double
getter/setter pair
y double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
toString() String
A string representation of this object.
inherited
update() → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited