ExplosionParticle class
Constructors
-
ExplosionParticle(Offset position, List<
Color> colors)
Properties
- angle ↔ double
-
getter/setter pair
- color ↔ Color
-
getter/setter pair
-
colors
→ List<
Color> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lifeSpan ↔ double
-
getter/setter pair
- position → Offset
-
final
- radius ↔ double
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- speed ↔ double
-
getter/setter pair
- x ↔ double
-
getter/setter pair
- y ↔ double
-
getter/setter pair
Methods
-
isAlive(
) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → void -
toString(
) → String -
A string representation of this object.
inherited
-
update(
) → void -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited