FireworkParticle class
Constructors
-
FireworkParticle(List<
Color> colors, Offset position, Size screenSize)
Properties
-
burstParticles
↔ List<
BurstParticle> -
getter/setter pair
- burstSpeed ↔ double
-
getter/setter pair
- color ↔ Color
-
getter/setter pair
-
colors
→ List<
Color> -
final
- hasBurst ↔ bool
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- position → Offset
-
final
- radius ↔ double
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenSize → Size
-
final
- speed ↔ double
-
getter/setter pair
- x ↔ double
-
getter/setter pair
- y ↔ double
-
getter/setter pair
Methods
-
burst(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → void -
toString(
) → String -
A string representation of this object.
inherited
-
update(
) → void -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited